@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2015-2020 Dmitry V. Levin <ldv@altlinux.org>
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -11,3 +11,5 @@ CAP_SYSLOG,
 CAP_WAKE_ALARM,
 CAP_BLOCK_SUSPEND,
 CAP_AUDIT_READ,
+CAP_PERFMON,
+CAP_BPF,
