@@ -140,15 +140,16 @@ SYS_FUNC(clone)
 
 struct strace_clone_args {
 	uint64_t flags;
-	uint64_t /* int * */ pidfd;
-	uint64_t /* int * */ child_tid;
-	uint64_t /* int * */ parent_tid;
-	uint64_t /* int */   exit_signal;
-	uint64_t stack;
+	uint64_t /* fd * */    pidfd;
+	uint64_t /* pid_t * */ child_tid;
+	uint64_t /* pid_t * */ parent_tid;
+	uint64_t /* int */     exit_signal;
+	uint64_t /* void * */  stack;
 	uint64_t stack_size;
-	uint64_t tls;
-	uint64_t set_tid;
+	uint64_t /* struct user_desc * / void * */ tls;
+	uint64_t /* pid_t * */ set_tid;
 	uint64_t set_tid_size;
+	uint64_t cgroup;
 };
 
 SYS_FUNC(clone3)
@@ -215,6 +216,10 @@ SYS_FUNC(clone3)
 			PRINT_FIELD_U(", ", arg, set_tid_size);
 		}
 
+		if (fetch_size > offsetof(struct strace_clone_args, cgroup)
+		    && (arg.cgroup || arg.flags & CLONE_INTO_CGROUP))
+			PRINT_FIELD_U(", ", arg, cgroup);
+
 		if (size > fetch_size)
 			print_nonzero_bytes(tcp, ", ", addr, fetch_size,
 					    MIN(size, get_pagesize()),
