@@ -3,7 +3,7 @@
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995, 1996 Rick Sladkey <jrs@world.std.com>
  * Copyright (c) 1996-1999 Wichert Akkerman <wichert@cistron.nl>
- * Copyright (c) 1999-2018 The strace developers.
+ * Copyright (c) 1999-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -11,6 +11,7 @@
 
 #include "defs.h"
 #include "flock.h"
+#include "print_fields.h"
 
 #include "xlat/f_owner_types.h"
 #include "xlat/f_seals.h"
@@ -20,16 +21,14 @@
 #include "xlat/notifyflags.h"
 
 static void
-print_struct_flock64(const struct_kernel_flock64 *fl, const int getlk)
+print_struct_flock64(struct tcb *const tcp, const struct_kernel_flock64 *fl, const int getlk)
 {
-	tprints("{l_type=");
-	printxval(lockfcmds, (unsigned short) fl->l_type, "F_???");
-	tprints(", l_whence=");
-	printxval(whence_codes, (unsigned short) fl->l_whence, "SEEK_???");
-	tprintf(", l_start=%" PRId64 ", l_len=%" PRId64,
-		(int64_t) fl->l_start, (int64_t) fl->l_len);
+	PRINT_FIELD_XVAL("{", *fl, l_type, lockfcmds, "F_???");
+	PRINT_FIELD_XVAL(", ", *fl, l_whence, whence_codes, "SEEK_???");
+	PRINT_FIELD_D(", ", *fl, l_start);
+	PRINT_FIELD_D(", ", *fl, l_len);
 	if (getlk)
-		tprintf(", l_pid=%lu", (unsigned long) fl->l_pid);
+		PRINT_FIELD_D(", ", *fl, l_pid);
 	tprints("}");
 }
 
@@ -39,7 +38,7 @@ printflock64(struct tcb *const tcp, const kernel_ulong_t addr, const int getlk)
 	struct_kernel_flock64 fl;
 
 	if (fetch_struct_flock64(tcp, addr, &fl))
-		print_struct_flock64(&fl, getlk);
+		print_struct_flock64(tcp, &fl, getlk);
 }
 
 static void
@@ -48,7 +47,7 @@ printflock(struct tcb *const tcp, const kernel_ulong_t addr, const int getlk)
 	struct_kernel_flock64 fl;
 
 	if (fetch_struct_flock(tcp, addr, &fl))
-		print_struct_flock64(&fl, getlk);
+		print_struct_flock64(tcp, &fl, getlk);
 }
 
 static void
@@ -59,9 +58,9 @@ print_f_owner_ex(struct tcb *const tcp, const kernel_ulong_t addr)
 	if (umove_or_printaddr(tcp, addr, &owner))
 		return;
 
-	tprints("{type=");
-	printxval(f_owner_types, owner.type, "F_OWNER_???");
-	tprintf(", pid=%d}", owner.pid);
+	PRINT_FIELD_XVAL("{", owner, type, f_owner_types, "F_OWNER_???");
+	PRINT_FIELD_D(", ", owner, pid);
+	tprints("}");
 }
 
 static int
