@@ -3,7 +3,7 @@
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995, 1996 Rick Sladkey <jrs@world.std.com>
  * Copyright (c) 1996-2001 Wichert Akkerman <wichert@cistron.nl>
- * Copyright (c) 1999-2019 The strace developers.
+ * Copyright (c) 1999-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -13,6 +13,29 @@
 #include <linux/ioctl.h>
 #include "xlat/ioctl_dirs.h"
 
+#if defined(SPARC) || defined(SPARC64)
+/*
+ * While Alpha, MIPS, PA-RISC, and POWER simply define _IOC_SIZEBITS to 13
+ * and utilise 3 bits for _IOC_DIRBITS, SPARC tries to provide 14 bits
+ * for the size field ("as on i386") by (ab)using the lowest direction bit.
+ * Unfortunately, while doing so, they decide to define _IOC_SIZE to 0
+ * when the direction doesn't have _IOC_READ/_IOC_WRITE bits set, which
+ * breaks the invariant
+ *
+ *     _IOC_SIZE(_IOC(dir, type, nr, size)) == size
+ *
+ * for _IOC_DIR(val) that doesn't include _IOC_READ or _IOC_WRITE, which
+ * is unacceptable for strace's use case.
+ * So, let's redefine _IOC_SIZE in a way that is more suitable for us.
+ */
+# undef _IOC_SIZE
+# define _IOC_SIZE(nr)						\
+	((_IOC_DIR(nr) & (_IOC_WRITE | _IOC_READ))		\
+		? (((nr) >> _IOC_SIZESHIFT) & _IOC_XSIZEMASK)	\
+		: (((nr) >> _IOC_SIZESHIFT) & _IOC_SIZEMASK))	\
+	/* end of _IOC_SIZE definition */
+#endif
+
 static int
 compare(const void *a, const void *b)
 {
@@ -85,7 +108,7 @@ evdev_decode_number(const unsigned int code)
 	if (nr >= 0x20 && nr <= 0x20 + 0x1f) {
 		tprints("EVIOCGBIT(");
 		if (nr == 0x20)
-			tprintf("0");
+			tprints("0");
 		else
 			printxval_ex(evdev_ev, nr - 0x20,
 				     abbrev ? "EV_???" : NULL,
@@ -102,35 +125,35 @@ evdev_decode_number(const unsigned int code)
 	}
 
 	switch (nr) {
-		case 0x06:
-			tprintf("EVIOCGNAME(%u)", _IOC_SIZE(code));
-			return 1;
-		case 0x07:
-			tprintf("EVIOCGPHYS(%u)", _IOC_SIZE(code));
-			return 1;
-		case 0x08:
-			tprintf("EVIOCGUNIQ(%u)", _IOC_SIZE(code));
-			return 1;
-		case 0x09:
-			tprintf("EVIOCGPROP(%u)", _IOC_SIZE(code));
-			return 1;
-		case 0x0a:
-			tprintf("EVIOCGMTSLOTS(%u)", _IOC_SIZE(code));
-			return 1;
-		case 0x18:
-			tprintf("EVIOCGKEY(%u)", _IOC_SIZE(code));
-			return 1;
-		case 0x19:
-			tprintf("EVIOCGLED(%u)", _IOC_SIZE(code));
-			return 1;
-		case 0x1a:
-			tprintf("EVIOCGSND(%u)", _IOC_SIZE(code));
-			return 1;
-		case 0x1b:
-			tprintf("EVIOCGSW(%u)", _IOC_SIZE(code));
-			return 1;
-		default:
-			return 0;
+	case 0x06:
+		tprintf("EVIOCGNAME(%u)", _IOC_SIZE(code));
+		return 1;
+	case 0x07:
+		tprintf("EVIOCGPHYS(%u)", _IOC_SIZE(code));
+		return 1;
+	case 0x08:
+		tprintf("EVIOCGUNIQ(%u)", _IOC_SIZE(code));
+		return 1;
+	case 0x09:
+		tprintf("EVIOCGPROP(%u)", _IOC_SIZE(code));
+		return 1;
+	case 0x0a:
+		tprintf("EVIOCGMTSLOTS(%u)", _IOC_SIZE(code));
+		return 1;
+	case 0x18:
+		tprintf("EVIOCGKEY(%u)", _IOC_SIZE(code));
+		return 1;
+	case 0x19:
+		tprintf("EVIOCGLED(%u)", _IOC_SIZE(code));
+		return 1;
+	case 0x1a:
+		tprintf("EVIOCGSND(%u)", _IOC_SIZE(code));
+		return 1;
+	case 0x1b:
+		tprintf("EVIOCGSW(%u)", _IOC_SIZE(code));
+		return 1;
+	default:
+		return 0;
 	}
 }
 
@@ -139,31 +162,34 @@ hiddev_decode_number(const unsigned int code)
 {
 	if (_IOC_DIR(code) == _IOC_READ) {
 		switch (_IOC_NR(code)) {
-			case 0x04:
-				tprintf("HIDIOCGRAWNAME(%u)", _IOC_SIZE(code));
-				return 1;
-			case 0x05:
-				tprintf("HIDIOCGRAWPHYS(%u)", _IOC_SIZE(code));
-				return 1;
-			case 0x06:
-				tprintf("HIDIOCSFEATURE(%u)", _IOC_SIZE(code));
-				return 1;
-			case 0x12:
-				tprintf("HIDIOCGPHYS(%u)", _IOC_SIZE(code));
-				return 1;
-			default:
-				return 0;
+		case 0x04:
+			tprintf("HIDIOCGRAWNAME(%u)", _IOC_SIZE(code));
+			return 1;
+		case 0x05:
+			tprintf("HIDIOCGRAWPHYS(%u)", _IOC_SIZE(code));
+			return 1;
+		case 0x06:
+			tprintf("HIDIOCSFEATURE(%u)", _IOC_SIZE(code));
+			return 1;
+		case 0x08:
+			tprintf("HIDIOCGRAWUNIQ(%u)", _IOC_SIZE(code));
+			return 1;
+		case 0x12:
+			tprintf("HIDIOCGPHYS(%u)", _IOC_SIZE(code));
+			return 1;
+		default:
+			return 0;
 		}
 	} else if (_IOC_DIR(code) == (_IOC_READ | _IOC_WRITE)) {
 		switch (_IOC_NR(code)) {
-			case 0x06:
-				tprintf("HIDIOCSFEATURE(%u)", _IOC_SIZE(code));
-				return 1;
-			case 0x07:
-				tprintf("HIDIOCGFEATURE(%u)", _IOC_SIZE(code));
-				return 1;
-			default:
-				return 0;
+		case 0x06:
+			tprintf("HIDIOCSFEATURE(%u)", _IOC_SIZE(code));
+			return 1;
+		case 0x07:
+			tprintf("HIDIOCGFEATURE(%u)", _IOC_SIZE(code));
+			return 1;
+		default:
+			return 0;
 		}
 	}
 
@@ -176,39 +202,39 @@ ioctl_decode_command_number(struct tcb *tcp)
 	const unsigned int code = tcp->u_arg[1];
 
 	switch (_IOC_TYPE(code)) {
-		case 'E':
-			return evdev_decode_number(code);
-		case 'H':
-			return hiddev_decode_number(code);
-		case 'M':
-			if (_IOC_DIR(code) == _IOC_WRITE) {
-				tprintf("MIXER_WRITE(%u)", _IOC_NR(code));
-				return 1;
-			} else if (_IOC_DIR(code) == _IOC_READ) {
-				tprintf("MIXER_READ(%u)", _IOC_NR(code));
-				return 1;
-			}
-			return 0;
-		case 'U':
-			if (_IOC_DIR(code) == _IOC_READ && _IOC_NR(code) == 0x2c) {
-				tprintf("UI_GET_SYSNAME(%u)", _IOC_SIZE(code));
-				return 1;
-			}
-			return 0;
-		case 'j':
-			if (_IOC_DIR(code) == _IOC_READ && _IOC_NR(code) == 0x13) {
-				tprintf("JSIOCGNAME(%u)", _IOC_SIZE(code));
-				return 1;
-			}
-			return 0;
-		case 'k':
-			if (_IOC_DIR(code) == _IOC_WRITE && _IOC_NR(code) == 0) {
-				tprintf("SPI_IOC_MESSAGE(%u)", _IOC_SIZE(code));
-				return 1;
-			}
-			return 0;
-		default:
-			return 0;
+	case 'E':
+		return evdev_decode_number(code);
+	case 'H':
+		return hiddev_decode_number(code);
+	case 'M':
+		if (_IOC_DIR(code) == _IOC_WRITE) {
+			tprintf("MIXER_WRITE(%u)", _IOC_NR(code));
+			return 1;
+		} else if (_IOC_DIR(code) == _IOC_READ) {
+			tprintf("MIXER_READ(%u)", _IOC_NR(code));
+			return 1;
+		}
+		return 0;
+	case 'U':
+		if (_IOC_DIR(code) == _IOC_READ && _IOC_NR(code) == 0x2c) {
+			tprintf("UI_GET_SYSNAME(%u)", _IOC_SIZE(code));
+			return 1;
+		}
+		return 0;
+	case 'j':
+		if (_IOC_DIR(code) == _IOC_READ && _IOC_NR(code) == 0x13) {
+			tprintf("JSIOCGNAME(%u)", _IOC_SIZE(code));
+			return 1;
+		}
+		return 0;
+	case 'k':
+		if (_IOC_DIR(code) == _IOC_WRITE && _IOC_NR(code) == 0) {
+			tprintf("SPI_IOC_MESSAGE(%u)", _IOC_SIZE(code));
+			return 1;
+		}
+		return 0;
+	default:
+		return 0;
 	}
 }
 
