@@ -22,6 +22,7 @@ typedef struct NAME_OF_STRUCT_MSQID_DS msqid_ds_t;
 
 #include MPERS_DEFS
 
+#include "print_fields.h"
 #include "xlat/msgctl_flags.h"
 
 static void
@@ -37,11 +38,9 @@ print_msqid_ds(struct tcb *const tcp, const kernel_ulong_t addr, int cmd)
 		if (umove_or_printaddr(tcp, addr, &msqid_ds))
 			return;
 
-		tprints("{msg_perm={");
-		printuid("uid=", msqid_ds.msg_perm.uid);
-		printuid(", gid=", msqid_ds.msg_perm.gid);
-		tprints(", mode=");
-		print_numeric_umode_t(msqid_ds.msg_perm.mode);
+		PRINT_FIELD_UID("{msg_perm={", msqid_ds.msg_perm, uid);
+		PRINT_FIELD_UID(", ", msqid_ds.msg_perm, gid);
+		PRINT_FIELD_NUMERIC_UMODE_T(", ", msqid_ds.msg_perm, mode);
 
 		if (cmd != IPC_STAT) {
 			tprints("}, ...}");
@@ -50,16 +49,16 @@ print_msqid_ds(struct tcb *const tcp, const kernel_ulong_t addr, int cmd)
 
 		tprintf(", key=%u",
 			(unsigned) msqid_ds.msg_perm.NAME_OF_STRUCT_IPC_PERM_KEY);
-		printuid(", cuid=", msqid_ds.msg_perm.cuid);
-		printuid(", cgid=", msqid_ds.msg_perm.cgid);
+		PRINT_FIELD_UID(", ", msqid_ds.msg_perm, cuid);
+		PRINT_FIELD_UID(", ", msqid_ds.msg_perm, cgid);
 		tprints("}");
 		tprintf(", msg_stime=%u", (unsigned) msqid_ds.msg_stime);
 		tprintf(", msg_rtime=%u", (unsigned) msqid_ds.msg_rtime);
 		tprintf(", msg_ctime=%u", (unsigned) msqid_ds.msg_ctime);
 		tprintf(", msg_qnum=%u", (unsigned) msqid_ds.msg_qnum);
 		tprintf(", msg_qbytes=%u", (unsigned) msqid_ds.msg_qbytes);
-		tprintf(", msg_lspid=%u", (unsigned) msqid_ds.msg_lspid);
-		tprintf(", msg_lrpid=%u", (unsigned) msqid_ds.msg_lrpid);
+		PRINT_FIELD_D(", ", msqid_ds, msg_lspid);
+		PRINT_FIELD_D(", ", msqid_ds, msg_lrpid);
 		tprints("}");
 		break;
 
