@@ -102,7 +102,7 @@
 [ 94] = { 1,	TP|SE,		SEN(exit),			"exit_group"		},
 [ 95] = { 5,	TP,		SEN(waitid),			"waitid"		},
 [ 96] = { 1,	0,		SEN(set_tid_address),		"set_tid_address"	},
-[ 97] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[ 97] = { 1,	0,		SEN(unshare),			"unshare"		},
 [ 98] = { 6,	0,		SEN(futex_time64),		"futex"			},
 [ 99] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [100] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
@@ -134,16 +134,16 @@
 [126] = { 1,	0,		SEN(sched_get_priority_min),	"sched_get_priority_min"},
 [127] = { 2,	0,		SEN(sched_rr_get_interval_time64),"sched_rr_get_interval"},
 [128] = { 0,	0,		SEN(restart_syscall),		"restart_syscall"	},
-[129] = { 2,	TS,		SEN(kill),			"kill"			},
-[130] = { 2,	TS,		SEN(kill),			"tkill"			},
-[131] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[129] = { 2,	TS|TP,		SEN(kill),			"kill"			},
+[130] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
+[131] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [132] = { 2,	TS,		SEN(sigaltstack),		"sigaltstack"		},
 [133] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [134] = { 4,	TS,		SEN(rt_sigaction),		"rt_sigaction"		},
 [135] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [136] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [137] = { 4,	TS,		SEN(rt_sigtimedwait_time64),	"rt_sigtimedwait"	},
-[138] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[138] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [139] = { 0,	TS,		SEN(rt_sigreturn),		"rt_sigreturn"		},
 [140] = { 3,	0,		SEN(setpriority),		"setpriority"		},
 [141] = { 2,	0,		SEN(getpriority),		"getpriority"		},
@@ -281,7 +281,7 @@
 [288] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [289] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
 [290] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
-[291] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[291] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [292] = { 6,	0,		SEN(io_pgetevents_time64),	"io_pgetevents"		},
 [293] = { 4,	0,		SEN(rseq),			"rseq"			},
 [294] = { 5,	TD,		SEN(kexec_file_load),		"kexec_file_load"	},
