@@ -40,7 +40,7 @@
 [ 34] = { 1,	0,		SEN(nice),			"nice"			},
 [ 35] = { 3,	TN,		SEN(accept),			"accept"		},
 [ 36] = { 0,	0,		SEN(sync),			"sync"			},
-[ 37] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 37] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 38] = { 2,	TF,		SEN(rename),			"rename"		},
 [ 39] = { 2,	TF,		SEN(mkdir),			"mkdir"			},
 [ 40] = { 1,	TF,		SEN(rmdir),			"rmdir"			},
@@ -181,7 +181,7 @@
 [175] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [176] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [177] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
-[178] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[178] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [179] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [180] = { 3,	TF,		SEN(chown),			"chown"			},
 [181] = { 5,	TN,		SEN(setsockopt),		"setsockopt"		},
@@ -211,7 +211,7 @@
 [205] = { 5,	0,		SEN(printargs),			"acl_set"		},
 [206] = { 0,	PU|NF,		SEN(gettid),			"gettid"		},
 [207] = { 4,	TD,		SEN(readahead),			"readahead"		},
-[208] = { 2,	TS,		SEN(kill),			"tkill"			},
+[208] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [209] = { 4,	TD|TN,		SEN(sendfile64),		"sendfile64"		},
 [210] = { 6,	0,		SEN(futex_time32),		"futex"			},
 [211] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
@@ -262,7 +262,7 @@
 [256] = { 2,	TCL,		SEN(clock_gettime32),		"clock_gettime"		},
 [257] = { 2,	TCL,		SEN(clock_getres_time32),	"clock_getres"		},
 [258] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
-[259] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[259] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [260] = { 6,	TM,		SEN(mbind),			"mbind"			},
 [261] = { 5,	TM,		SEN(get_mempolicy),		"get_mempolicy"		},
 [262] = { 3,	TM,		SEN(set_mempolicy),		"set_mempolicy"		},
@@ -291,7 +291,7 @@
 [285] = { 4,	TD|TF,		SEN(readlinkat),		"readlinkat"		},
 [286] = { 3,	TD|TF,		SEN(fchmodat),			"fchmodat"		},
 [287] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
-[288] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[288] = { 1,	0,		SEN(unshare),			"unshare"		},
 [289] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [290] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
 [291] = { 6,	TD,		SEN(splice),			"splice"		},
@@ -352,7 +352,7 @@
 [346] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
 [347] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
 [348] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
-[349] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[349] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [350] = { 6,	0,		SEN(io_pgetevents_time32),	"io_pgetevents"		},
 [351] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [352] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
