@@ -49,7 +49,7 @@
 [BASE_NR +  26] = { 0,	0,		SEN(sync),			"sync"			},
 [BASE_NR +  27] = { 1,	TD,		SEN(fsync),			"fsync"			},
 [BASE_NR +  28] = { 1,	TD,		SEN(fdatasync),			"fdatasync"		},
-[BASE_NR +  29] = { 2,	TS,		SEN(kill),			"kill"			},
+[BASE_NR +  29] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [BASE_NR +  30] = { 2,	TF,		SEN(rename),			"rename"		},
 [BASE_NR +  31] = { 2,	TF,		SEN(mkdir),			"mkdir"			},
 [BASE_NR +  32] = { 1,	TF,		SEN(rmdir),			"rmdir"			},
@@ -176,7 +176,7 @@
 [BASE_NR + 153] = { 4,	TS,		SEN(rt_sigaction),		"rt_sigaction"		},
 [BASE_NR + 154] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [BASE_NR + 155] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
-[BASE_NR + 156] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[BASE_NR + 156] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [BASE_NR + 157] = { 0,	TS,		SEN(rt_sigreturn),		"rt_sigreturn"		},
 [BASE_NR + 158] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [BASE_NR + 159] = { 4,	TS,		SEN(rt_sigtimedwait_time64),	"rt_sigtimedwait"	},
@@ -225,13 +225,13 @@
 [BASE_NR + 202] = { 2,	TF,		SEN(removexattr),		"removexattr"		},
 [BASE_NR + 203] = { 2,	TF,		SEN(removexattr),		"lremovexattr"		},
 [BASE_NR + 204] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
-[BASE_NR + 205] = { 2,	TS,		SEN(kill),			"tkill"			},
+[BASE_NR + 205] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [BASE_NR + 206] = { 6,	0,		SEN(futex_time64),		"futex"			},
 [BASE_NR + 207] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
 [BASE_NR + 208] = { 3,	0,		SEN(sched_getaffinity),		"sched_getaffinity"	},
 [BASE_NR + 209] = { 1,	0,		SEN(set_tid_address),		"set_tid_address"	},
 [BASE_NR + 210] = { 4,	TD,		SEN(fadvise64),			"fadvise64"		},
-[BASE_NR + 211] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[BASE_NR + 211] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [BASE_NR + 212] = { 1,	TP|SE,		SEN(exit),			"exit_group"		},
 [BASE_NR + 213] = { 3,	0,		SEN(lookup_dcookie),		"lookup_dcookie"	},
 [BASE_NR + 214] = { 2,	TM,		SEN(io_setup),			"io_setup"		},
@@ -292,7 +292,7 @@
 [BASE_NR + 269] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [BASE_NR + 270] = { 6,	TD,		SEN(pselect6_time64),		"pselect6"		},
 [BASE_NR + 271] = { 5,	TD,		SEN(ppoll_time64),		"ppoll"			},
-[BASE_NR + 272] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[BASE_NR + 272] = { 1,	0,		SEN(unshare),			"unshare"		},
 [BASE_NR + 273] = { 6,	TD,		SEN(splice),			"splice"		},
 [BASE_NR + 274] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [BASE_NR + 275] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
@@ -346,7 +346,7 @@
 [BASE_NR + 323] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
 [BASE_NR + 324] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
 [BASE_NR + 325] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
-[BASE_NR + 326] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[BASE_NR + 326] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [BASE_NR + 327] = { 6,	0,		SEN(io_pgetevents_time64),	"io_pgetevents"		},
 [BASE_NR + 328] = { 5,	TD,		SEN(perf_event_open),		"perf_event_open"	},
 [BASE_NR + 329] = { 3,	0,		SEN(seccomp),			"seccomp"		},
