@@ -44,7 +44,7 @@
 [ 34] = { 1,	0,		SEN(nice),			"nice"			},
 [ 35] = { 0,	0,		SEN(ftime),			"ftime"			},
 [ 36] = { 0,	0,		SEN(sync),			"sync"			},
-[ 37] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 37] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 38] = { 2,	TF,		SEN(rename),			"rename"		},
 [ 39] = { 2,	TF,		SEN(mkdir),			"mkdir"			},
 [ 40] = { 1,	TF,		SEN(rmdir),			"rmdir"			},
@@ -185,7 +185,7 @@
 [175] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [176] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [177] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
-[178] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[178] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [179] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [180] = { 5,	TD,		SEN(pread),			"pread64"		},
 [181] = { 5,	TD,		SEN(pwrite),			"pwrite64"		},
@@ -228,7 +228,7 @@
 [218 ... 219] = { },
 [220] = { 3,	TD,		SEN(getdents64),		"getdents64"		},
 [221] = { 0,	PU|NF,		SEN(gettid),			"gettid"		},
-[222] = { 2,	TS,		SEN(kill),			"tkill"			},
+[222] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [223] = { 5,	TF,		SEN(setxattr),			"setxattr"		},
 [224] = { 5,	TF,		SEN(setxattr),			"lsetxattr"		},
 [225] = { 5,	TD,		SEN(fsetxattr),			"fsetxattr"		},
@@ -271,7 +271,7 @@
 [262] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
 [263] = { 3,	TF|TSF|TSFA,	SEN(statfs64),			"statfs64"		},
 [264] = { 3,	TD|TFSF|TSFA,	SEN(fstatfs64),			"fstatfs64"		},
-[265] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[265] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [266] = { 2,	TF,		SEN(utimes),			"utimes"		},
 [267] = { 6,	TD,		SEN(fadvise64_64),		"fadvise64_64"		},
 [268] = { 6,	TM,		SEN(mbind),			"mbind"			},
@@ -309,7 +309,7 @@
 [300] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [301] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
 [302] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
-[303] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[303] = { 1,	0,		SEN(unshare),			"unshare"		},
 [304] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [305] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
 [306] = { 6,	TD,		SEN(splice),			"splice"		},
@@ -385,7 +385,7 @@
 [376] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
 [377] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
 [378] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
-[379] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[379] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [380] = { 3,	0,		SEN(seccomp),			"seccomp"		},
 [381] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [382] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
