@@ -68,7 +68,7 @@
 [BASE_NR +  57] = { 3,	TF|TP|TSD|SE|SI,	SEN(execve),			"execve"		},
 [BASE_NR +  58] = { 1,	TP|SE,		SEN(exit),			"exit"			},
 [BASE_NR +  59] = { 4,	TP,		SEN(wait4),			"wait4"			},
-[BASE_NR +  60] = { 2,	TS,		SEN(kill),			"kill"			},
+[BASE_NR +  60] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [BASE_NR +  61] = { 1,	0,		SEN(uname),			"uname"			},
 [BASE_NR +  62] = { 3,	TI,		SEN(semget),			"semget"		},
 [BASE_NR +  63] = { 3,	TI,		SEN(semop),			"semop"			},
@@ -135,7 +135,7 @@
 [BASE_NR + 124] = { 2,	TC,		SEN(capset),			"capset"		},
 [BASE_NR + 125] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [BASE_NR + 126] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
-[BASE_NR + 127] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[BASE_NR + 127] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [BASE_NR + 128] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [BASE_NR + 129] = { 2,	TS,		SEN(sigaltstack),		"sigaltstack"		},
 [BASE_NR + 130] = { 2,	TF,		SEN(utime),			"utime"			},
@@ -200,7 +200,7 @@
 [BASE_NR + 189] = { 2,	TF,		SEN(removexattr),		"removexattr"		},
 [BASE_NR + 190] = { 2,	TF,		SEN(removexattr),		"lremovexattr"		},
 [BASE_NR + 191] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
-[BASE_NR + 192] = { 2,	TS,		SEN(kill),			"tkill"			},
+[BASE_NR + 192] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [BASE_NR + 193] = { 1,	TCL,		SEN(time),			"time"			},
 [BASE_NR + 194] = { 6,	0,		SEN(futex_time32),		"futex"			},
 [BASE_NR + 195] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
@@ -237,7 +237,7 @@
 [BASE_NR + 226] = { 2,	TCL,		SEN(clock_gettime32),		"clock_gettime"		},
 [BASE_NR + 227] = { 2,	TCL,		SEN(clock_getres_time32),	"clock_getres"		},
 [BASE_NR + 228] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
-[BASE_NR + 229] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[BASE_NR + 229] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [BASE_NR + 230] = { 2,	TF,		SEN(utimes),			"utimes"		},
 [BASE_NR + 231] = { 6,	TM,		SEN(mbind),			"mbind"			},
 [BASE_NR + 232] = { 5,	TM,		SEN(get_mempolicy),		"get_mempolicy"		},
@@ -274,7 +274,7 @@
 [BASE_NR + 263] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [BASE_NR + 264] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
 [BASE_NR + 265] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
-[BASE_NR + 266] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[BASE_NR + 266] = { 1,	0,		SEN(unshare),			"unshare"		},
 [BASE_NR + 267] = { 6,	TD,		SEN(splice),			"splice"		},
 [BASE_NR + 268] = { 4,	TD,		SEN(sync_file_range),		"sync_file_range"	},
 [BASE_NR + 269] = { 4,	TD,		SEN(tee),			"tee"			},
@@ -338,7 +338,7 @@
 [BASE_NR + 327] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [BASE_NR + 328] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
 [BASE_NR + 329] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
-[BASE_NR + 330] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[BASE_NR + 330] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [BASE_NR + 331] = { 4,	0,		SEN(rseq),			"rseq"			},
 [BASE_NR + 332] = { 6,	0,		SEN(io_pgetevents_time32),	"io_pgetevents"		},
 # include "syscallent-common-32.h"
