@@ -46,7 +46,7 @@
 [BASE_NR +  34] = { 1,	0,		SEN(nice),			"nice"			},
 [BASE_NR +  35] = { 1,	0,		SEN(ftime),			"ftime"			},
 [BASE_NR +  36] = { 0,	0,		SEN(sync),			"sync"			},
-[BASE_NR +  37] = { 2,	TS,		SEN(kill),			"kill"			},
+[BASE_NR +  37] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [BASE_NR +  38] = { 2,	TF,		SEN(rename),			"rename"		},
 [BASE_NR +  39] = { 2,	TF,		SEN(mkdir),			"mkdir"			},
 [BASE_NR +  40] = { 1,	TF,		SEN(rmdir),			"rmdir"			},
@@ -207,7 +207,7 @@
 [BASE_NR + 195] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [BASE_NR + 196] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [BASE_NR + 197] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
-[BASE_NR + 198] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[BASE_NR + 198] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [BASE_NR + 199] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [BASE_NR + 200] = { 6,	TD,		SEN(pread),			"pread64"		},
 [BASE_NR + 201] = { 6,	TD,		SEN(pwrite),			"pwrite64"		},
@@ -245,7 +245,7 @@
 [BASE_NR + 233] = { 2,	TF,		SEN(removexattr),		"removexattr"		},
 [BASE_NR + 234] = { 2,	TF,		SEN(removexattr),		"lremovexattr"		},
 [BASE_NR + 235] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
-[BASE_NR + 236] = { 2,	TS,		SEN(kill),			"tkill"			},
+[BASE_NR + 236] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [BASE_NR + 237] = { 4,	TD|TN,		SEN(sendfile64),		"sendfile64"		},
 [BASE_NR + 238] = { 6,	0,		SEN(futex_time32),		"futex"			},
 [BASE_NR + 239] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
@@ -275,7 +275,7 @@
 [BASE_NR + 263] = { 2,	TCL,		SEN(clock_gettime32),		"clock_gettime"		},
 [BASE_NR + 264] = { 2,	TCL,		SEN(clock_getres_time32),	"clock_getres"		},
 [BASE_NR + 265] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
-[BASE_NR + 266] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[BASE_NR + 266] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [BASE_NR + 267] = { 2,	TF,		SEN(utimes),			"utimes"		},
 [BASE_NR + 268] = { 6,	TM,		SEN(mbind),			"mbind"			},
 [BASE_NR + 269] = { 5,	TM,		SEN(get_mempolicy),		"get_mempolicy"		},
@@ -312,7 +312,7 @@
 [BASE_NR + 300] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [BASE_NR + 301] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
 [BASE_NR + 302] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
-[BASE_NR + 303] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[BASE_NR + 303] = { 1,	0,		SEN(unshare),			"unshare"		},
 [BASE_NR + 304] = { 6,	TD,		SEN(splice),			"splice"		},
 [BASE_NR + 305] = { 7,	TD,		SEN(sync_file_range),		"sync_file_range"	},
 [BASE_NR + 306] = { 4,	TD,		SEN(tee),			"tee"			},
@@ -375,7 +375,7 @@
 [BASE_NR + 363] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [BASE_NR + 364] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
 [BASE_NR + 365] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
-[BASE_NR + 366] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[BASE_NR + 366] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [BASE_NR + 367] = { 4,	0,		SEN(rseq),			"rseq"			},
 [BASE_NR + 368] = { 6,	0,		SEN(io_pgetevents_time32),	"io_pgetevents"		},
 /* room for arch specific calls */
