@@ -44,7 +44,7 @@
 [ 34] = { 1,	0,		SEN(nice),			"nice"			},
 [ 35] = { 0,	0,		SEN(ftime),			"ftime"			},
 [ 36] = { 0,	0,		SEN(sync),			"sync"			},
-[ 37] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 37] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 38] = { 2,	TF,		SEN(rename),			"rename"		},
 [ 39] = { 2,	TF,		SEN(mkdir),			"mkdir"			},
 [ 40] = { 1,	TF,		SEN(rmdir),			"rmdir"			},
@@ -184,7 +184,7 @@
 [174] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [175] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [176] = { 4,	TS,		SEN(rt_sigtimedwait_time64),	"rt_sigtimedwait"	},
-[177] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[177] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [178] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [179] = { 4,	TD,		SEN(pread),			"pread64"		},
 [180] = { 4,	TD,		SEN(pwrite),			"pwrite64"		},
@@ -210,7 +210,7 @@
 [205] = { 3,	TM,		SEN(madvise),			"madvise"		},
 [206] = { 3,	TM,		SEN(mincore),			"mincore"		},
 [207] = { 0,	PU|NF,		SEN(gettid),			"gettid"		},
-[208] = { 2,	TS,		SEN(kill),			"tkill"			},
+[208] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [209] = { 5,	TF,		SEN(setxattr),			"setxattr"		},
 [210] = { 5,	TF,		SEN(setxattr),			"lsetxattr"		},
 [211] = { 5,	TD,		SEN(fsetxattr),			"fsetxattr"		},
@@ -252,7 +252,7 @@
 [247] = { 2,	TCL,		SEN(clock_getres_time64),	"clock_getres"		},
 [248] = { 4,	0,		SEN(clock_nanosleep_time64),	"clock_nanosleep"	},
 [249] = { 2,	0,		SEN(printargs),			"swapcontext"		},
-[250] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[250] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [251] = { 2,	TF,		SEN(utimes),			"utimes"		},
 [252] = { 3,	TF|TSF|TSFA,	SEN(statfs64),			"statfs64"		},
 [253] = { 3,	TD|TFSF|TSFA,	SEN(fstatfs64),			"fstatfs64"		},
@@ -284,7 +284,7 @@
 [279] = { 4,	0,		SEN(printargs),			"spu_create"		},
 [280] = { 6,	TD,		SEN(pselect6_time64),		"pselect6"		},
 [281] = { 5,	TD,		SEN(ppoll_time64),		"ppoll"			},
-[282] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[282] = { 1,	0,		SEN(unshare),			"unshare"		},
 [283] = { 6,	TD,		SEN(splice),			"splice"		},
 [284] = { 4,	TD,		SEN(tee),			"tee"			},
 [285] = { 4,	TD,		SEN(vmsplice),			"vmsplice"		},
@@ -374,7 +374,7 @@
 [380] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
 [381] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
 [382] = { 5,	TD,		SEN(kexec_file_load),		"kexec_file_load"	},
-[383] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[383] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [384] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
 [385] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
 [386] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
