@@ -46,7 +46,7 @@
 [ 34] = { 1,	0,		SEN(nice),			"nice"			},
 [ 35] = { },
 [ 36] = { 0,	0,		SEN(sync),			"sync"			},
-[ 37] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 37] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 38] = { 2,	TF,		SEN(rename),			"rename"		},
 [ 39] = { 2,	TF,		SEN(mkdir),			"mkdir"			},
 [ 40] = { 1,	TF,		SEN(rmdir),			"rmdir"			},
@@ -187,7 +187,7 @@
 [175] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [176] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [177] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
-[178] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[178] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [179] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [180] = { 5,	TD,		SEN(pread),			"pread64"		},
 [181] = { 5,	TD,		SEN(pwrite),			"pwrite64"		},
@@ -246,11 +246,11 @@
 [234] = { 2,	TF,		SEN(removexattr),		"lremovexattr"		},
 [235] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
 [236] = { 0,	PU|NF,		SEN(gettid),			"gettid"		},
-[237] = { 2,	TS,		SEN(kill),			"tkill"			},
+[237] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [238] = { 6,	0,		SEN(futex_time32),		"futex"			},
 [239] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
 [240] = { 3,	0,		SEN(sched_getaffinity),		"sched_getaffinity"	},
-[241] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[241] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [242] = { },
 [243] = { 2,	TM,		SEN(io_setup),			"io_setup"		},
 [244] = { 1,	TM,		SEN(io_destroy),		"io_destroy"		},
@@ -312,7 +312,7 @@
 [300] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [301] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
 [302] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
-[303] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[303] = { 1,	0,		SEN(unshare),			"unshare"		},
 [304] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [305] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
 [306] = { 6,	TD,		SEN(splice),			"splice"		},
@@ -388,7 +388,7 @@
 [376] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
 [377] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
 [378] = { 2,	0,		SEN(s390_guarded_storage),	"s390_guarded_storage"	},
-[379] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[379] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [380] = { 4,	0,		SEN(s390_sthyi),		"s390_sthyi"		},
 [381] = { 5,	TD,		SEN(kexec_file_load),		"kexec_file_load"	},
 [382] = { 6,	0,		SEN(io_pgetevents_time32),	"io_pgetevents"		},
