@@ -44,7 +44,7 @@
 [ 34] = { 1,	0,		SEN(nice),			"nice"			},
 [ 35] = { 0,	0,		SEN(ftime),			"ftime"			},
 [ 36] = { 0,	0,		SEN(sync),			"sync"			},
-[ 37] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 37] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 38] = { 2,	TF,		SEN(rename),			"rename"		},
 [ 39] = { 2,	TF,		SEN(mkdir),			"mkdir"			},
 [ 40] = { 1,	TF,		SEN(rmdir),			"rmdir"			},
@@ -185,7 +185,7 @@
 [175] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [176] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [177] = { 4,	TS,		SEN(rt_sigtimedwait_time64),	"rt_sigtimedwait"	},
-[178] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[178] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [179] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [180] = { 4,	TD,		SEN(pread),			"pread64"		},
 [181] = { 4,	TD,		SEN(pwrite),			"pwrite64"		},
@@ -271,7 +271,7 @@
 [263] = { 2,	TF,		SEN(removexattr),		"removexattr"		},
 [264] = { 2,	TF,		SEN(removexattr),		"lremovexattr"		},
 [265] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
-[266] = { 2,	TS,		SEN(kill),			"tkill"			},
+[266] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [267] = { 4,	TD|TN,		SEN(sendfile64),		"sendfile64"		},
 [268] = { 6,	0,		SEN(futex_time64),		"futex"			},
 [269] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
@@ -302,7 +302,7 @@
 [295] = { 4,	0,		SEN(clock_nanosleep_time64),	"clock_nanosleep"	},
 [296] = { 3,	TF|TSF|TSFA,	SEN(statfs64),			"statfs64"		},
 [297] = { 3,	TD|TFSF|TSFA,	SEN(fstatfs64),			"fstatfs64"		},
-[298] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[298] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [299] = { 2,	TF,		SEN(utimes),			"utimes"		},
 [300] = { 4,	TD,		SEN(fadvise64_64),		"fadvise64_64"		},
 [301] = { },
@@ -342,7 +342,7 @@
 [335] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [336] = { 6,	TD,		SEN(pselect6_time64),		"pselect6"		},
 [337] = { 5,	TD,		SEN(ppoll_time64),		"ppoll"			},
-[338] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[338] = { 1,	0,		SEN(unshare),			"unshare"		},
 [339] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [340] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
 [341] = { 6,	TD,		SEN(splice),			"splice"		},
