@@ -41,7 +41,7 @@
 [ 34] = { 1,	0,		SEN(nice),			"nice"			},
 [ 35] = { },
 [ 36] = { 0,	0,		SEN(sync),			"sync"			},
-[ 37] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 37] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 38] = { 2,	TF|TST|TSTA,	SEN(stat),			"stat"			},
 [ 39] = { 4,	TD|TN,		SEN(sendfile),			"sendfile"		},
 [ 40] = { 2,	TF|TLST|TSTA,	SEN(lstat),			"lstat"			},
@@ -109,7 +109,7 @@
 [103] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [104] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [105] = { 4,	TS,		SEN(rt_sigtimedwait_time64),	"rt_sigtimedwait"	},
-[106] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[106] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [107] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [108] = { 3,	TC,		SEN(setresuid),			"setresuid"		},
 [109] = { 3,	TC,		SEN(getresuid),			"getresuid"		},
@@ -190,7 +190,7 @@
 [184] = { 5,	0,		SEN(query_module),		"query_module"		},
 [185] = { 2,	0,		SEN(setpgid),			"setpgid"		},
 [186] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
-[187] = { 2,	TS,		SEN(kill),			"tkill"			},
+[187] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [188] = { 1,	TP|SE,		SEN(exit),			"exit_group"		},
 [189] = { 1,	0,		SEN(uname),			"uname"			},
 [190] = { 3,	0,		SEN(init_module),		"init_module"		},
@@ -214,7 +214,7 @@
 [208] = { 3,	0,		SEN(lookup_dcookie),		"lookup_dcookie"	},
 [209] = { 4,	TD,		SEN(fadvise64),			"fadvise64"		},
 [210] = { 4,	TD,		SEN(fadvise64_64),		"fadvise64_64"		},
-[211] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[211] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [212] = { 3,	TP,		SEN(waitpid),			"waitpid"		},
 [213] = { 1,	TF,		SEN(swapoff),			"swapoff"		},
 [214] = { 1,	0,		SEN(sysinfo),			"sysinfo"		},
@@ -302,7 +302,7 @@
 [296] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [297] = { 6,	TD,		SEN(pselect6_time64),		"pselect6"		},
 [298] = { 5,	TD,		SEN(ppoll_time64),		"ppoll"			},
-[299] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[299] = { 1,	0,		SEN(unshare),			"unshare"		},
 [300] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [301] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
 [302] = { 4,	TM,		SEN(migrate_pages),		"migrate_pages"		},
@@ -363,7 +363,7 @@
 [357] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
 [358] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
 [359] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
-[360] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[360] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [361] = { 6,	0,		SEN(io_pgetevents_time64),	"io_pgetevents"		},
 [362] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [363] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
