@@ -67,7 +67,7 @@
 [ 59] = { 3,	TF|TP|TSD|SE|SI,	SEN(execve),			"execve"		},
 [ 60] = { 1,	TP|SE,		SEN(exit),			"exit"			},
 [ 61] = { 4,	TP,		SEN(wait4),			"wait4"			},
-[ 62] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 62] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 63] = { 1,	0,		SEN(uname),			"uname"			},
 [ 64] = { 3,	TI,		SEN(semget),			"semget"		},
 [ 65] = { 3,	TI,		SEN(semop),			"semop"			},
@@ -134,7 +134,7 @@
 [126] = { 2,	TC,		SEN(capset),			"capset"		},
 [127] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [128] = { 4,	TS,		SEN(rt_sigtimedwait_time64),	"rt_sigtimedwait"	},
-[129] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[129] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [130] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [131] = { 2,	TS,		SEN(sigaltstack),		"sigaltstack"		},
 [132] = { 2,	TF,		SEN(utime),			"utime"			},
@@ -163,7 +163,7 @@
 [155] = { 2,	TF,		SEN(pivotroot),			"pivot_root"		},
 [156] = { 1,	0,		SEN(sysctl),			"_sysctl"		},
 [157] = { 5,	TC,		SEN(prctl),			"prctl"			},
-[158] = { 2,	TP,		SEN(arch_prctl),		"arch_prctl"		},
+[158] = { 2,	0,		SEN(arch_prctl),		"arch_prctl"		},
 [159] = { 1,	TCL,		SEN(adjtimex64),		"adjtimex"		},
 [160] = { 2,	0,		SEN(setrlimit),			"setrlimit"		},
 [161] = { 1,	TF,		SEN(chroot),			"chroot"		},
@@ -205,7 +205,7 @@
 [197] = { 2,	TF,		SEN(removexattr),		"removexattr"		},
 [198] = { 2,	TF,		SEN(removexattr),		"lremovexattr"		},
 [199] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
-[200] = { 2,	TS,		SEN(kill),			"tkill"			},
+[200] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [201] = { 1,	TCL,		SEN(time),			"time"			},
 [202] = { 6,	0,		SEN(futex_time64),		"futex"			},
 [203] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
@@ -239,7 +239,7 @@
 [231] = { 1,	TP|SE,		SEN(exit),			"exit_group"		},
 [232] = { 4,	TD,		SEN(epoll_wait),		"epoll_wait"		},
 [233] = { 4,	TD,		SEN(epoll_ctl),			"epoll_ctl"		},
-[234] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[234] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [235] = { 2,	TF,		SEN(utimes),			"utimes"		},
 [236] = { 5,	0,		SEN(vserver),			"vserver"		},
 [237] = { 6,	TM,		SEN(mbind),			"mbind"			},
@@ -277,7 +277,7 @@
 [269] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [270] = { 6,	TD,		SEN(pselect6_time64),		"pselect6"		},
 [271] = { 5,	TD,		SEN(ppoll_time64),		"ppoll"			},
-[272] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[272] = { 1,	0,		SEN(unshare),			"unshare"		},
 [273] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [274] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
 [275] = { 6,	TD,		SEN(splice),			"splice"		},
@@ -337,7 +337,7 @@
 [329] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [330] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
 [331] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
-[332] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[332] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [333] = { 6,	0,		SEN(io_pgetevents_time64),	"io_pgetevents"		},
 [334] = { 4,	0,		SEN(rseq),			"rseq"			},
 /* [335 ... 423] - reserved to sync up with other architectures */
