@@ -123,9 +123,9 @@
 [120] = { 0,	PU|NF,		SEN(getpid),			"getpid"		},
 [121] = { 4,	TP,		SEN(wait4),			"wait4"			},
 [122] = { 5,	TP,		SEN(waitid),			"waitid"		},
-[123] = { 2,	TS,		SEN(kill),			"kill"			},
-[124] = { 2,	TS,		SEN(kill),			"tkill"			},
-[125] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[123] = { 2,	TS|TP,		SEN(kill),			"kill"			},
+[124] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
+[125] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [126] = { 1,	0,		SEN(set_tid_address),		"set_tid_address"	},
 [127] = { 0,	PU|NF,		SEN(gettid),			"gettid"		},
 [128] = { 0,	0,		SEN(setsid),			"setsid"		},
@@ -227,7 +227,7 @@
 [227] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [228] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [229] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
-[230] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[230] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [231] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [232] = { 4,	TD,		SEN(mq_open),			"mq_open"		},
 [233] = { 1,	0,		SEN(mq_unlink),			"mq_unlink"		},
@@ -263,7 +263,7 @@
 [263] = { 6,	TM,		SEN(mbind),			"mbind"			},
 [264] = { 5,	TM,		SEN(get_mempolicy),		"get_mempolicy"		},
 [265] = { 3,	TM,		SEN(set_mempolicy),		"set_mempolicy"		},
-[266] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[266] = { 1,	0,		SEN(unshare),			"unshare"		},
 [267] = { 6,	TM,		SEN(move_pages),		"move_pages"		},
 [268] = { 6,	TD,		SEN(splice),			"splice"		},
 [269] = { 4,	TD,		SEN(tee),			"tee"			},
@@ -346,7 +346,7 @@
 [348] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [349] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
 [350] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
-[351] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[351] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [352] = { 4,	0,		SEN(rseq),			"rseq"			},
 /* [353 ... 402] - reserved to sync up with other architectures */
 #include "syscallent-common-32.h"
