@@ -6,7 +6,7 @@
  * Copyright (c) 1999 IBM Deutschland Entwicklung GmbH, IBM Corporation
  *                     Linux for s390 port by D.J. Barrow
  *                    <barrow_dj@mail.yahoo.com,djbarrow@de.ibm.com>
- * Copyright (c) 2001-2019 The strace developers.
+ * Copyright (c) 1999-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -446,6 +446,15 @@ SYS_FUNC(kill)
 	return RVAL_DECODED;
 }
 
+SYS_FUNC(tkill)
+{
+	tprintf("%d", (int) tcp->u_arg[0]);
+	tprints(", ");
+	printsignal(tcp->u_arg[1]);
+
+	return RVAL_DECODED;
+}
+
 SYS_FUNC(tgkill)
 {
 	/* tgid, tid */
