@@ -1,12 +1,16 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include "scno.h"
+
+#ifdef __NR_gettimeofday
+
 #include <assert.h>
 #include <stdio.h>
 #include <stdint.h>
@@ -64,3 +68,9 @@ main(void)
 	puts("+++ exited with 0 +++");
 	return 0;
 }
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_gettimeofday")
+
+#endif /* __NR_gettimeofday */
